PCB Environment: NetOverrides Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
NetOverrides Class Reference

## Public Member Functions
void | load (PyObject *)
Micrometers | traceWidth (const std::string &net, Micrometers) const
Micrometers | viaDiameter (const std::string &net, Micrometers) const
Micrometers | clearance (const std::string &net, Micrometers) const
std::string | str () const

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/Factory.hpp